mafw.timer
==========

.. automodule:: mafw.timer

   
   .. rubric:: Functions

   .. autosummary::
   
      pretty_format_duration
      rreplace
   
   .. rubric:: Classes

   .. autosummary::
   
      Timer
   